<?php

/*
  Plugin Name: Tickera - Check-in Availability Ticket Template Element
  Plugin URI: http://tickera.com/
  Description: Additional ticket template element that shows ticket check-in availability.
  Author: Tickera.com
  Author URI: http://tickera.com/
  Version: 1.2
  TextDomain: tc-validity-element
  Domain Path: /languages/
  Copyright 2021 Tickera (http://tickera.com/)
 */



if ( !defined( 'ABSPATH' ) )
	exit; // Exit if accessed directly



if ( !class_exists( 'TC_custom_template_date_availibility' ) ) {



	class TC_custom_template_date_availibility {

		var $version = '1.2';
		var $title = 'Tickera - Checkin Date Availability Ticket Template Element';
		var $name = 'tickera-custom-template-date-availability';
		var $dir_name = 'tickera-custom-date-availibility-element';
		var $location = 'plugins';
		var $plugin_dir = '';
		var $plugin_url = '';

		function __construct() {

			$this->init_vars();

			add_action( 'plugins_loaded', array( &$this, 'load_ticket_template_elements' ) );
		}

		function init_vars() {



			if ( defined( 'WP_PLUGIN_URL' ) && defined( 'WP_PLUGIN_DIR' ) && file_exists( WP_PLUGIN_DIR . '/' . $this->dir_name . '/' . basename( __FILE__ ) ) ) {

				$this->location = 'subfolder-plugins';

				$this->plugin_dir = WP_PLUGIN_DIR . '/' . $this->dir_name . '/';

				$this->plugin_url = plugins_url( '/', __FILE__ );
			} else if ( defined( 'WP_PLUGIN_URL' ) && defined( 'WP_PLUGIN_DIR' ) && file_exists( WP_PLUGIN_DIR . '/' . basename( __FILE__ ) ) ) {

				$this->location = 'plugins';

				$this->plugin_dir = WP_PLUGIN_DIR . '/';

				$this->plugin_url = plugins_url( '/', __FILE__ );
			} else if ( is_multisite() && defined( 'WPMU_PLUGIN_URL' ) && defined( 'WPMU_PLUGIN_DIR' ) && file_exists( WPMU_PLUGIN_DIR . '/' . basename( __FILE__ ) ) ) {

				$this->location = 'mu-plugins';

				$this->plugin_dir = WPMU_PLUGIN_DIR;

				$this->plugin_url = WPMU_PLUGIN_URL;
			} else {

				wp_die( sprintf( __( 'There was an issue determining where %s is installed. Please reinstall it.', 'tc' ), $this->title ) );
			}
		}

		function load_ticket_template_elements() {

			//get ticket elements dir

			$dir = $this->plugin_dir . 'ticket-elements/';



			$ticket_template_elements = array();



			if ( !is_dir( $dir ) )
				return;

			if ( !$dh = opendir( $dir ) )
				return;

			while ( ( $plugin = readdir( $dh ) ) !== false ) {

				if ( substr( $plugin, -4 ) == '.php' )
					$ticket_template_elements[] = $dir . '/' . $plugin;
			}

			closedir( $dh );

			sort( $ticket_template_elements );



			foreach ( $ticket_template_elements as $file )
				include( $file );



			do_action( 'tc_load_custom_ticket_date_availibility_element' );
		}

    function localization() {
        if ( 'mu-plugins' == $this->location ) {
            load_muplugin_textdomain( 'tc-validity-element', 'languages/' );
        } elseif ( 'subfolder-plugins' == $this->location ) {
            load_plugin_textdomain('tc-validity-element', false, dirname(plugin_basename(__FILE__)) . '/languages/');
        } elseif ( ‘plugins’ == $this->location ) {
            load_plugin_textdomain( 'tc-validity-element', false, 'languages/' );
        }
        $temp_locales = explode( ‘_’, get_locale() );
        $this->language = ($temp_locales[0]) ? $temp_locales[0] : 'en';
    }

	}

}



$TC_custom_template_date_availibility = new TC_custom_template_date_availibility();

