<?php

class tc_ticket_validity_element extends TC_Ticket_Template_Elements {

    var $element_name = 'tc_ticket_validity_element';
    var $element_title = 'Ticket Validity';
    var $font_awesome_icon = '<i class="fa fa-check" aria-hidden="true"></i>';

    function on_creation() {
        $this->element_title = apply_filters('tc_ticket_validity_element_title', __('Ticket Validity', 'tc-validity-element'));
    }

    function admin_content() {
        echo $this->get_font_sizes();
        echo $this->get_font_style();
        echo $this->get_font_colors();
        echo $this->get_cell_alignment();
        echo $this->get_element_margins();
        $this->ticket_content();
    }

    function ticket_content($ticket_instance_id = false, $ticket_type_id = false) {

        $ticket_type_id = get_post_meta($ticket_instance_id, 'ticket_type_id', true);
        $ticket_checkin_availability = get_post_meta($ticket_type_id, '_ticket_checkin_availability', true);
        $post_type = get_post_type($ticket_type_id);

        if ($post_type == 'product_variation') {
            $ticket_type_id = wp_get_post_parent_id($ticket_type_id);
        }

        if ($ticket_instance_id) {

            switch ($ticket_checkin_availability) {

                case'open_ended' :
                    $tc_show_availability = __('Ticket can be checked-in at any time', 'tc-validity-element');
                    break;

                case 'range' :
                    $from_date = get_post_meta($ticket_type_id, '_ticket_checkin_availability_from_date', true);
                    $to_date = get_post_meta($ticket_type_id, '_ticket_checkin_availability_to_date', true);
                    $from_date_formatted = date_i18n(get_option('date_format'), strtotime($from_date));
                    $from_time_formatted = date_i18n(get_option('time_format'), strtotime($from_date));
                    $to_date_formatted = date_i18n(get_option('date_format'), strtotime($to_date));
                    $to_time_formatted = date_i18n(get_option('time_format'), strtotime($to_date));

                    $tc_show_availability = __('Ticket can be checked-in from ', 'tc-validity-element') . $from_date_formatted . __(' @ ', 'tc-validity-element') . $from_time_formatted . __(' to ', 'tc-validity-element') . $to_date_formatted . __(' @ ', 'tc-validity-element') . $to_time_formatted;
                    break;


                case 'time_after_order' :
                    $days_after_order = get_post_meta($ticket_type_id, '_time_after_order_days', true);
                    $hours_after_order = get_post_meta($ticket_type_id, '_time_after_order_hours', true);
                    $minutes_after_order = get_post_meta($ticket_type_id, '_time_after_order_minutes', true);
                    $seconds_after_order = ($days_after_order * 24 * 60 * 60) + ($hours_after_order * 60 * 60) + ($minutes_after_order * 60);
                    $order_date = get_post_datetime($ticket_instance_id)->format('Y-m-d H:i:s');
                    $after_order_availability_seconds = strtotime($order_date) + $seconds_after_order;
                    $after_order_date_formatted = date_i18n(get_option('date_format'), $after_order_availability_seconds);
                    $after_order_time_formatted = date_i18n(get_option('time_format'), $after_order_availability_seconds);

                    $tc_show_availability = __('Ticket can be checked-in until: ', 'tc-validity-element') . $after_order_date_formatted . __(' @ ', 'tc-validity-element') . $after_order_time_formatted;
                    break;


                case 'upon_event_starts':
                    $event_id = get_post_meta($ticket_instance_id, 'event_id', true);
                    $event_start_date_time_raw = get_post_meta($event_id, 'event_date_time', true);
                    $event_date_formatted = date_i18n(get_option('date_format'), strtotime($event_start_date_time_raw));
                    $event_time_formatted = date_i18n(get_option('time_format'), strtotime($event_start_date_time_raw));

                    $tc_show_availability = __('Ticket can be checked-in from: ', 'tc-validity-element') . $event_date_formatted . __(' @ ', 'tc-validity-element') . $event_time_formatted;
                    break;

                case 'time_after_first_checkin':
                    $days_after_checkin = get_post_meta($ticket_type_id, '_time_after_first_checkin_days', true);
                    $hours_after_checkin = get_post_meta($ticket_type_id, '_time_after_first_checkin_hours', true);
                    $minutes_after_checkin = get_post_meta($ticket_type_id, '_time_after_first_checkin_minutes', true);

                    $tc_show_availability = __('Ticket can be checked-in for another ', 'tc-validity-element') . $days_after_checkin . __(' day(s) ', 'tc-validity-element') . $hours_after_checkin . __(' hour(s) and ','tc-validity-element') . $minutes_after_checkin . __(' minutes after first check-in', 'tc-validity-element');
                    break;
            }

            return $tc_show_availability;

        } else {

            return apply_filters('tc_ticket_description_element_default', __('Check-In Availability: <br/>', 'tc') . __('2017-02-16 12:16 - 2017-02-28 12:16', 'tc'));
        }
    }

}

tc_register_template_element('tc_ticket_validity_element', __('Ticket Validity', 'tc-validity-element'));
